/*
                    Manual Page Viewer: File IO
 */

#ifndef VIEWERFIO_H
#define VIEWERFIO_H

#include <gtk/gtk.h>
#include "viewer.h"


extern gint ViewerOpenFile(
	viewer_struct *v, const gchar *filename, const gchar *name
);


#endif	/* VIEWERFIO_H */
